@@ -96,7 +96,7 @@ static gboolean cupboard_icon_clicked(TangleButton *tanglebutton, gpointer data)
 	//This is hack.  FIXME: for some reason we can't just call this.
 	g_timeout_add(100,themeselection_load,data);
 
-
+	g_free(filename);
 	return FALSE;
 }
 
@@ -129,8 +129,6 @@ void add_cursor( JammoSequencer* sequencer, ClutterActor* parent) {
 	gfloat width,height;
 	clutter_actor_get_size(texture_image, &width, &height);
 	
-	printf("korkeus %f\n",height);
-	
 	cursor = jammo_cursor_new(sequencer, texture_image);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 480.0-height-2);
@@ -154,7 +152,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer_old, gpointer none) {
 	printf("Sequencer '%p' stopped\n", sequencer_old);
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
 	
 	//Show cupboard
 	ClutterActor* view = jammo_get_actor_by_id("cupboard-view");
@@ -198,6 +196,7 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 	fd = open(filename,O_RDONLY);
 	if (fd == -1) //File not found
 		{  //no track for this language,. use  common comping.
+		g_free(filename);
 		filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,name); //try without language postfix
 		}
 	printf("looking for file '%s' for comping_track\n",filename);
@@ -233,6 +232,7 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 	gchar *new_name = g_strdup_printf("song-%s-view",name);
 	ClutterActor* new_view;
 	new_view = jammo_get_actor_by_id(new_name);	
+	g_free(new_name);
 	clutter_actor_show(new_view);
 
 	//And start sequencer after animation is completed
@@ -288,11 +288,13 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		char* theme_name =  strtok(NULL, "+");
 		char* variation_name = strtok(NULL, "+");
 		char* easy  = strtok(NULL, "+");
-	
+
 		ClutterActor* icon;
 		gchar* icon_filename;
-		if (theme_name == NULL || variation_name == NULL || easy == NULL) //This means, we couldn't tokenizer it -> do not show it at all
+		if (theme_name == NULL || variation_name == NULL || easy == NULL) {
+			g_free(filename);
 			break;
+		}
 		
 		if (strncmp(theme_name,"fantasy",7)==0) 
 		{
@@ -308,20 +310,25 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		}
 		else //now we have hardcoded theme names TODO.  Not correct theme name -> do not show it at all
 		{
+			g_free(filename);
 			break;
 		}
 
 
 		icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file(icon_filename, NULL), clutter_texture_new_from_file(icon_filename, NULL));
-		g_object_set(icon,"depth-position", -1, "width", 60.0, "height", 60.0, "x", 50.0,  "y", 20+counter1*94.0, NULL);
+		g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 30.0,  "y", 7+counter1*94.0, NULL);
 		
 		clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
 		clutter_actor_set_reactive(icon,TRUE);
-		g_signal_connect (icon, "clicked", G_CALLBACK (cupboard_icon_clicked),l->data);
+		g_signal_connect_data(icon, "clicked", G_CALLBACK (cupboard_icon_clicked),l->data,(GClosureNotify) g_free,0);
 		counter1++;
+		
+		g_free(filename);
 		}
 
 	
+	g_list_free(files);
+	
 	//And singings
 	filepath1 = SINGINGS_DIRECTORY;
 
@@ -350,7 +357,7 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file(icon_filename, NULL), clutter_texture_new_from_file(icon_filename, NULL));
 		g_free(icon_filename);
 
-		g_object_set(icon,"depth-position", -1, "width", 60.0, "height", 60.0, "x", 190.0,  "y", 20+counter2*94.0, NULL);
+		g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 197.0,  "y", 7+counter2*94.0, NULL);
 
 		clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
 		
@@ -361,6 +368,9 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		g_free(name2);
 		counter2++;
 		}
+		
+	g_list_foreach(files, (GFunc)g_free, NULL);
+	g_list_free(files);
 
 		int counter = counter1>counter2?counter1:counter2; //max(counter1,counter2);
 		//make movable shelves
