@@ -854,7 +854,7 @@ gboolean start_midi_editor(gpointer data) {
 	ClutterActor* view;
 
 	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
 	
 	view = tangle_view_new();   //This can be defined in json too.
 	clutter_container_add(CLUTTER_CONTAINER(mainview), view, NULL);
